Clover genotype analysis: scripts for figure generation and statistical analyses
===

This repository provides the R scripts, raw data, and intermediate output data files used to generate the figures and statistical analyses in the manuscript by Fields et al. "Rhizobium nodule diversity and composition is influenced by clover host selection and local growth conditions", currently under review for publication.

The R scripts and raw data are provided in this repository to enable regeneration of the data analysis undertaken in the study. The figures and intermediate data files generated within the scripts are also saved here. The scripts have been edited so that all folders can be downloaded and the files run locally on a user's computer. The working directory is hard-coded and will need to be altered by the user for the scripts to run - user's should set the working directory to be the scripts/ directory.

The following directories are included:



## scripts/
-----

The following scripts are organised into separate R scripts. All scripts include comments detailing the code function at each step.


**clovergenotype_genospeciesdifferences_analysis.R** containing analysis of field data and ***Figure 4*** graph generation.

**clovergenotype_greenhouse_experiment_braycurtis_NMDS_PV_pseudorep.R** containing analysis of greenhouse data and ***Figure 6*** and ***Supplementary Figures*** graph generation.

**clovergenotype_greenhouse_plantgrowth_gsfrequencies_vs_plantgrowth_analyses.R** containing analysis of greenhouse data and ***Figure 6*** and ***Supplementary Figures*** graph generation.

**clovergenotype_greenhouse_plantgrowth_standardisation.R** containing analysis of greenhouse data.

**clovergenotype_NMDS_block1plots_klondikeonlyplots_analysis.R** containing analysis of field data and ***Figure 4***, ***Figure 5*** and ***Supplementary Figures*** graph generation. 

**clovergenotype_spatial_braycurtisheatmaps_PERMANOVA_analysis.R** containing analysis of field data and ***Figure 4***, ***Figure 5*** and ***Supplementary Figures*** graph generation.

**clovergenotype_strainphenotype_analysis.R** containing analysis of Rhizobium in vitro culture data and ***Supplementary Figures*** graph generation.

**clovergenotype_variancepartitioning_analysis.R** containing analysis of field data analysis and ***Figure 5*** graph generation.

**clovergenotype_venn_heatmap_analysis.R** used for analysis of field data and ***Figure 2*** graph generation.

**summarySE.R** used for some of the statistical analyses in the above scripts. 



## data/raw_data/
-----

The following raw data files are organised into separate folders depending on which experimental data is being used.

The MAUIcount_output_* directories contain the MAUI-seq pipeline output files from processing of the field data sequencing files. There is an output directory for each of the four genes analysed (noda, nodd, reca, rpob): https://doi.org/10.1111/1755-0998.13294

## MAUIcount_output_noda
## MAUIcount_output_nodd
## MAUIcount_output_reca
## MAUIcount_output_rpob

The remaining directories in the raw_data directory path include:

## abundance_data
contains formatted MAUI-seq output files of the field data for analysis. Also includes field sample metadata.

## greenhouse_experiment
contains formatted MAUI-seq output files of the greenhouse data for analysis. Also includes greenhouse sample metadata.

## greenhouse_experiment_plantinfo
contains growth data for the plants grown in the greenhouse experiment. Raw data files collected from previously published papers referenced in the manuscript:
https://doi.org/10.3389/fpls.2020.01181
https://doi.org/10.1007/s00122-021-03955-3

## strain_phenotype_data
contains Rhizobium strains in vitro growth and biofilm data. 




## data/data_output
-----

A folder containing the expected output data files and figures generated by the scripts. (For user reference). They are categorised into the following directories:

## abundance_data

## figures

## greenhouse_abundance_data_pseudorep

## greenhouse_experiment_plantinfo

## stats_data



---------
---
Author: Bryden Fields - bryden.fields@york.ac.uk